<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Təyyarə rejimi aktiv edildi</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Təyyarə rejimi söndürülüb</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Söndür</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktiv et</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Təyyarə rejimi</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Təyyarə rejimi ayarları</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Təyyarə rejimi</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Cihazlarım</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth ayarları</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Söndürülüb</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Söndürmək</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Açmaq</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth ayarları</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 qoşuldu</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Qoşulur...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Söndürüldü</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>%1 qoşuldu</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Qoşulmayıb</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Söndürülüb</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Parlaqlıq</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Ekran ayarları</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Ekran ayarları</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Parlaqlıq</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Baz</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>B.er</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Ç.ax</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Çər</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>C.ax</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Cüm</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Şnb</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Klaviatura qatı əlavə etmək</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Tarix və vaxt</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 saat vaxt formatı</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 saat vaxt formatı</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Vaxt ayarları</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Təqvimi açın</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Bazar ertəsi</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Çərşənbə axşamı</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Çərşənbə</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Cümə axşamı</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Cümə</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Şənbə</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Bazar</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>bazar ertəsi</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>çərşənbə axşamı</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>çərşənbə</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>cümə axşamı</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>cümə</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>şənbə</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>bazar</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Başqa cihazlar</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>&quot;Narahat etmə&quot; rejimi</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>&quot;Narahat etmə&quot; rejimi ayarları</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Söndürün</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Açın</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>&quot;Narahat etmə&quot; rejimi açıqdır</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>&quot;Narahat etmə&quot; rejimi söndürülüb</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>&quot;Narahat etmə&quot; rejimi</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Göz rahatlığı</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Göz rahatlığı rejimi açıqdır</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Göz rahatlığı rejimi söndürülüb</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Ekran ayarları</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Göz rahatlığı</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Görünüş mövzusu</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Açıq</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Söndürülüb</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>İşıqlı</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Qaranlıq</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Avtomatik</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Göz rahatlığı rejimini söndürmək</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Göz rahatlığı rejimini aktiv etmək</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Ekran ayarları</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Görünüş mövzusu: İşıqlı</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Görünüş mövzusu: Qaranlıq</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Görünüş mövzusu: Avtomatik</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Vizual effekt</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>İşıqlı</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Qaranlıq</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Avtomatik</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Görünüş mövzusu</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>İsmarıc yoxdur</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Bildiriş ayarları</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Bildirişlər</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>DND rejimini söndürün</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>DND rejimini açın</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Bildiriş</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Ekran Klaviaturası</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tənzimləmələr</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Yüksək məhsuldarlıq</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Tarazlaşdırılmış</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Enerjiyə qənaət</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Yaxşı Yükləmə</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Elektrik qidalanması</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Elektrik enerjisi ayarları</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Tutum %1, %2 dəq qalır</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Tutum %1, %2 saat %3 dəq qalır</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Yüklənmə %1, dolmağa %2 dəq qalır</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Yüklənmə %1, dolmağa %2 saat %3 dəq qalır</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Tutum %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Yüklənmə %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Tutum %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Tutum %1, tam yükləndi</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Tutum %1, doldurulmur</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Batareya</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Doldurma, qalan dolma vaxtı hesablanır</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Qalan istifadə vaxtı hesablanır</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 dəq. qalır</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 saat %2 dəq. qalır</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Doldurulmur</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Tam dolub</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Doldurulur, tam dolmağa %1 dəq. qalır</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Doldurulur, tam dolmağa %1 saat %2 dəq. qalır</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Tutumu %1, %2 saat qalır</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 saat qalır</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>%1 doldurulur, tam dolmaya %2 saat qalır</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Doldurulur, tam dolmaya %1 saat qalır</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Elektrik enerjisi ayarları</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Musiqi</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Naməlum</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Sistemi söndür</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Gözlət</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Yuxu rejimi</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilidləmək</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Elektrik enerjisi ayarları</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yenidən başlatmaq</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Yenilə və Söndür</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Yenilə və Yenidən başlat</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Söndürmək</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>İstifadıçini dəyişmək</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Bu gün</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Ay təqvimi</translation>
    </message>
    <message>
        <source>y</source>
        <translation>i</translation>
    </message>
    <message>
        <source>m</source>
        <translation>a</translation>
    </message>
    <message>
        <source>d</source>
        <translation>g</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Bazar ertəsi</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Çərşənbə axşamı</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Çərşənbə</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Cümə axşamı</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Cümə</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Şənbə</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Bazar</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Yan</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Fev</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Mar</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Apr</translation>
    </message>
    <message>
        <source>May</source>
        <translation>May</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>İyn</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>İyl</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Avq</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Sent</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Okt</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Noy</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Dek</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Təqvimi açın</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>bazar ertəsi</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>çərşənbə axşamı</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>çərşənbə</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>cümə axşamı</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>cümə</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>şənbə</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>bazar</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Səs səviyyəsi</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Səs effektləri</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Səs</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Susdurun</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Səssiz</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Səs ayarları</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Səs çıxışı cihazları yoxdur</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Səs səviyyəsi %1</translation>
    </message>
</context>
</TS>